API docs for “spamfighter.core.commands.test.test_command.FakeCommand”

# Class s.c.c.t.t.FakeCommand(command.Command):

Part of spamfighter.core.commands.test.test_command View Source View In Hierarchy

Undocumented

Method | perform | Undocumented

Inherited from Command:

Method | __init__ | Конструктор команды
Method | getResponse | Сформировать результат команды как хэш, готовый к XML-RPC преобразованию.
Method | getParams | Сформировать параметры команды как хэш, готовый к XML-RPC преобразованию.
Method | checkParams | Проверить наличие всех необходимых параметров команды.
Method | checkResult | Проверить наличие всех необходимых полей в результате выполнения команды.
Method | init | Дополнительный метод, может переопределяться в потомках для выполнения процедуры
Method | finalize | Дополнительный метод, может переопределяться в потомках для выполнения завершения
Method | run | Выполнить команду.
Class | _ParamsWrapper | Класс-обертка для проверки корректности

def perform(self): (source)
Undocumented